@@ -2,9 +2,12 @@
 ## Author          : Jens Henrik Badsberg, Claus Dethlefsen, Luca La Rocca
 ## Created On      : Mon Mar 14 12:00:00 2005
 ## Last Modified By: Luca La Rocca
-## Last Modified On: Mon Mar 14 12:00:00 2005
-## Update Count    : 1
+## Last Modified On: Fri Feb 17 10:25:00 2006
+## Update Count    : 3
 ## Status          : Unknown, Use with caution!
 ######################################################
 
-.onLoad <- function(lib, pkg) require(methods)
+.onLoad <- function(lib, pkg){
+    require(graphics)
+    require(methods)
+}
